@@ -187,7 +187,8 @@ from utilities.polars import (
     week_num,
     write_dataframe,
     write_series,
-    zoned_datetime,
+    zoned_datetime_dtype,
+    zoned_datetime_period_dtype,
 )
 from utilities.random import get_state
 from utilities.sentinel import Sentinel, sentinel
@@ -1023,7 +1024,9 @@ class TestDataClassToDataFrame:
         ):
             df = dataclass_to_dataframe(objs, localns=locals())
         check_polars_dataframe(
-            df, height=len(objs), schema_list={"x": zoned_datetime(time_zone=time_zone)}
+            df,
+            height=len(objs),
+            schema_list={"x": zoned_datetime_dtype(time_zone=time_zone)},
         )
 
     def test_error_empty(self) -> None:
@@ -1117,7 +1120,7 @@ class TestDataClassToSchema:
 
         obj = Example()
         result = dataclass_to_schema(obj)
-        expected = {"x": zoned_datetime(time_zone=time_zone)}
+        expected = {"x": zoned_datetime_dtype(time_zone=time_zone)}
         assert result == expected
 
     def test_enum(self) -> None:
@@ -1249,7 +1252,7 @@ class TestDataClassToSchema:
 
         obj = Example()
         result = dataclass_to_schema(obj)
-        expected = {"x": zoned_datetime(time_zone=time_zone)}
+        expected = {"x": zoned_datetime_dtype(time_zone=time_zone)}
         assert result == expected
 
     @given(start=timezones(), end=timezones())
@@ -1269,12 +1272,7 @@ class TestDataClassToSchema:
 
         obj = Outer()
         result = dataclass_to_schema(obj, localns=locals())
-        expected = {
-            "inner": Struct({
-                "start": zoned_datetime(time_zone=start),
-                "end": zoned_datetime(time_zone=end),
-            })
-        }
+        expected = {"inner": zoned_datetime_period_dtype(time_zone=(start, end))}
         assert result == expected
 
     def test_containers(self) -> None:
@@ -1490,7 +1488,7 @@ class TestGetDataTypeOrSeriesTimeZone:
     def test_main(
         self, *, time_zone: ZoneInfo, case: Literal["dtype", "series"]
     ) -> None:
-        dtype = zoned_datetime(time_zone=time_zone)
+        dtype = zoned_datetime_dtype(time_zone=time_zone)
         match case:
             case "dtype":
                 dtype_or_series = dtype
@@ -2823,9 +2821,15 @@ class TestWeekNum:
         assert_series_equal(result, expected)
 
 
-class TestZonedDateTime:
-    @given(time_zone=sampled_from([HongKong, UTC]))
-    def test_main(self, *, time_zone: ZoneInfo) -> None:
-        dtype = zoned_datetime(time_zone=time_zone)
+class TestZonedDateTimeDType:
+    def test_main(self) -> None:
+        dtype = zoned_datetime_dtype(time_zone=UTC)
         assert isinstance(dtype, Datetime)
         assert dtype.time_zone is not None
+
+
+class TestZonedDateTimePeriodDType:
+    @given(time_zone=sampled_from([UTC, (UTC, UTC)]))
+    def test_main(self, *, time_zone: ZoneInfo | tuple[ZoneInfo, ZoneInfo]) -> None:
+        dtype = zoned_datetime_period_dtype(time_zone=time_zone)
+        assert isinstance(dtype, Struct)
