@@ -7,14 +7,10 @@ from hypothesis.strategies import DrawFn, booleans, composite, lists, none, samp
 from pytest import raises
 from sqlalchemy import URL, Column, Integer, MetaData, Table
 
-from utilities.hypothesis import integers, temp_paths, text_ascii
+from utilities.hypothesis import integers, temp_paths, text_ascii, urls
 from utilities.postgres import (
     _build_pg_dump,
     _build_pg_restore_or_psql,
-    _extract_url,
-    _ExtractURLDatabaseError,
-    _ExtractURLHostError,
-    _ExtractURLPortError,
     _path_pg_dump,
     _PGDumpFormat,
     _resolve_data_only_and_clean,
@@ -27,6 +23,8 @@ from utilities.typing import get_literal_elements
 if TYPE_CHECKING:
     from pathlib import Path
 
+    from utilities.types import MaybeListStr
+
 
 @composite
 def tables(draw: DrawFn, /) -> list[Table | str]:
@@ -38,34 +36,21 @@ def tables(draw: DrawFn, /) -> list[Table | str]:
     return [draw(sampled_from([n, t])) for n, t in zip(names, tables, strict=True)]
 
 
-@composite
-def urls(draw: DrawFn, /) -> URL:
-    username = draw(text_ascii(min_size=1) | none())
-    password = draw(text_ascii(min_size=1) | none())
-    host = draw(text_ascii(min_size=1))
-    port = draw(integers(min_value=1))
-    database = draw(text_ascii(min_size=1))
-    return URL.create(
-        drivername="postgres",
-        username=username,
-        password=password,
-        host=host,
-        port=port,
-        database=database,
-    )
-
-
 class TestPGDump:
-    @given(url=urls(), path=temp_paths(), logger=text_ascii(min_size=1) | none())
+    @given(
+        url=urls(all_=True), path=temp_paths(), logger=text_ascii(min_size=1) | none()
+    )
     async def test_main(self, *, url: URL, path: Path, logger: str | None) -> None:
         _ = await pg_dump(url, path, dry_run=True, logger=logger)
 
     @given(
-        url=urls(),
+        url=urls(all_=True),
         path=temp_paths(),
         format_=sampled_from(get_literal_elements(_PGDumpFormat)),
         jobs=integers(min_value=0) | none(),
         create=booleans(),
+        extension=lists(text_ascii(min_size=1)) | none(),
+        extension_exc=lists(text_ascii(min_size=1)) | none(),
         schema=lists(text_ascii(min_size=1)) | none(),
         schema_exc=lists(text_ascii(min_size=1)) | none(),
         table=tables() | none(),
@@ -83,6 +68,8 @@ class TestPGDump:
         format_: _PGDumpFormat,
         jobs: int | None,
         create: bool,
+        extension: MaybeListStr | None,
+        extension_exc: MaybeListStr | None,
         schema: list[str] | None,
         schema_exc: list[str] | None,
         table: list[Table | str] | None,
@@ -98,6 +85,8 @@ class TestPGDump:
             format_=format_,
             jobs=jobs,
             create=create,
+            extension=extension,
+            extension_exc=extension_exc,
             schema=schema,
             schema_exc=schema_exc,
             table=table,
@@ -129,15 +118,16 @@ class TestResolveDataOnlyAndClean:
 
 
 class TestRestore:
-    @given(url=urls(), path=temp_paths(), logger=text_ascii(min_size=1) | none())
+    @given(
+        url=urls(all_=True), path=temp_paths(), logger=text_ascii(min_size=1) | none()
+    )
     async def test_main(self, *, url: URL, path: Path, logger: str | None) -> None:
         _ = await restore(url, path, dry_run=True, logger=logger)
 
     @given(
-        url=urls(),
+        url=urls(all_=True),
         path=temp_paths(),
         psql=booleans(),
-        database=text_ascii(min_size=1) | none(),
         create=booleans(),
         jobs=integers(min_value=0) | none(),
         schema=lists(text_ascii(min_size=1)) | none(),
@@ -152,7 +142,6 @@ class TestRestore:
         url: URL,
         path: Path,
         psql: bool,
-        database: str | None,
         create: bool,
         jobs: int | None,
         schema: list[str] | None,
@@ -165,7 +154,6 @@ class TestRestore:
             url,
             path,
             psql=psql,
-            database=database,
             create=create,
             jobs=jobs,
             schema=schema,
@@ -174,27 +162,3 @@ class TestRestore:
             role=role,
             docker=docker,
         )
-
-
-class TestExtractURL:
-    def test_database(self) -> None:
-        url = URL.create("postgres")
-        with raises(
-            _ExtractURLDatabaseError,
-            match="Expected URL to contain a 'database'; got .*",
-        ):
-            _ = _extract_url(url)
-
-    def test_host(self) -> None:
-        url = URL.create("postgres", database="database")
-        with raises(
-            _ExtractURLHostError, match="Expected URL to contain a 'host'; got .*"
-        ):
-            _ = _extract_url(url)
-
-    def test_port(self) -> None:
-        url = URL.create("postgres", database="database", host="host")
-        with raises(
-            _ExtractURLPortError, match="Expected URL to contain a 'port'; got .*"
-        ):
-            _ = _extract_url(url)
