@@ -31,6 +31,7 @@ from utilities.text import (
     parse_bool,
     parse_none,
     repr_encode,
+    secret_str,
     snake_case,
     split_key_value_pairs,
     split_str,
@@ -105,6 +106,71 @@ class TestReprEncode:
         assert result == expected
 
 
+class TestSecretStr:
+    def test_main(self) -> None:
+        s = secret_str("text")
+        assert repr(s) == secret_str._REPR
+        assert str(s) == secret_str._REPR
+
+    def test_open(self) -> None:
+        s = secret_str("text")
+        assert isinstance(s.str, str)
+        assert not isinstance(s.str, secret_str)
+        assert repr(s.str) == repr("text")
+        assert str(s.str) == "text"
+
+
+class TestSnakeCase:
+    @given(
+        case=sampled_from([
+            ("API", "api"),
+            ("APIResponse", "api_response"),
+            ("ApplicationController", "application_controller"),
+            ("Area51Controller", "area51_controller"),
+            ("FreeBSD", "free_bsd"),
+            ("HTML", "html"),
+            ("HTMLTidy", "html_tidy"),
+            ("HTMLTidyGenerator", "html_tidy_generator"),
+            ("HTMLVersion", "html_version"),
+            ("NoHTML", "no_html"),
+            ("One   Two", "one_two"),
+            ("One  Two", "one_two"),
+            ("One Two", "one_two"),
+            ("OneTwo", "one_two"),
+            ("One_Two", "one_two"),
+            ("One__Two", "one_two"),
+            ("One___Two", "one_two"),
+            ("Product", "product"),
+            ("SpecialGuest", "special_guest"),
+            ("Text", "text"),
+            ("Text123", "text123"),
+            ("_APIResponse_", "_api_response_"),
+            ("_API_", "_api_"),
+            ("__APIResponse__", "_api_response_"),
+            ("__API__", "_api_"),
+            ("__impliedVolatility_", "_implied_volatility_"),
+            ("_itemID", "_item_id"),
+            ("_lastPrice__", "_last_price_"),
+            ("_symbol", "_symbol"),
+            ("aB", "a_b"),
+            ("changePct", "change_pct"),
+            ("changePct_", "change_pct_"),
+            ("impliedVolatility", "implied_volatility"),
+            ("lastPrice", "last_price"),
+            ("memMB", "mem_mb"),
+            ("sizeX", "size_x"),
+            ("symbol", "symbol"),
+            ("testNTest", "test_n_test"),
+            ("text", "text"),
+            ("text123", "text123"),
+        ])
+    )
+    def test_main(self, *, case: tuple[str, str]) -> None:
+        text, expected = case
+        result = snake_case(text)
+        assert result == expected
+
+
 class TestSplitKeyValuePairs:
     @given(
         case=sampled_from([
@@ -237,57 +303,6 @@ class TestSplitAndJoinStr:
             _ = split_str("1,(22,333", brackets=[("(", ")")])
 
 
-class TestSnakeCase:
-    @given(
-        case=sampled_from([
-            ("API", "api"),
-            ("APIResponse", "api_response"),
-            ("ApplicationController", "application_controller"),
-            ("Area51Controller", "area51_controller"),
-            ("FreeBSD", "free_bsd"),
-            ("HTML", "html"),
-            ("HTMLTidy", "html_tidy"),
-            ("HTMLTidyGenerator", "html_tidy_generator"),
-            ("HTMLVersion", "html_version"),
-            ("NoHTML", "no_html"),
-            ("One   Two", "one_two"),
-            ("One  Two", "one_two"),
-            ("One Two", "one_two"),
-            ("OneTwo", "one_two"),
-            ("One_Two", "one_two"),
-            ("One__Two", "one_two"),
-            ("One___Two", "one_two"),
-            ("Product", "product"),
-            ("SpecialGuest", "special_guest"),
-            ("Text", "text"),
-            ("Text123", "text123"),
-            ("_APIResponse_", "_api_response_"),
-            ("_API_", "_api_"),
-            ("__APIResponse__", "_api_response_"),
-            ("__API__", "_api_"),
-            ("__impliedVolatility_", "_implied_volatility_"),
-            ("_itemID", "_item_id"),
-            ("_lastPrice__", "_last_price_"),
-            ("_symbol", "_symbol"),
-            ("aB", "a_b"),
-            ("changePct", "change_pct"),
-            ("changePct_", "change_pct_"),
-            ("impliedVolatility", "implied_volatility"),
-            ("lastPrice", "last_price"),
-            ("memMB", "mem_mb"),
-            ("sizeX", "size_x"),
-            ("symbol", "symbol"),
-            ("testNTest", "test_n_test"),
-            ("text", "text"),
-            ("text123", "text123"),
-        ])
-    )
-    def test_main(self, *, case: tuple[str, str]) -> None:
-        text, expected = case
-        result = snake_case(text)
-        assert result == expected
-
-
 class TestStrEncode:
     @given(n=integers())
     def test_main(self, *, n: int) -> None:
