@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-import datetime as dt
 from collections.abc import Callable, Iterable, Iterator, Sequence
 from dataclasses import asdict, dataclass, is_dataclass
 from functools import _lru_cache_wrapper, cached_property, partial, reduce, wraps
 from inspect import getattr_static
+from pathlib import Path
 from re import findall
 from types import (
     BuiltinFunctionType,
@@ -17,55 +17,40 @@ from types import (
 from typing import (
     TYPE_CHECKING,
     Any,
-    Generic,
     Literal,
     TypeGuard,
-    TypeVar,
+    assert_never,
     cast,
     overload,
     override,
 )
 
-from typing_extensions import ParamSpec
+from whenever import Date, PlainDateTime, Time, TimeDelta, ZonedDateTime
 
 from utilities.reprlib import get_repr, get_repr_and_class
 from utilities.sentinel import Sentinel, sentinel
 from utilities.types import (
     Dataclass,
+    MaybeCallableBool,
     Number,
     StrMapping,
-    TCallable,
-    TCallable1,
-    TCallable2,
-    TSupportsRichComparison,
+    SupportsRichComparison,
     TupleOrStrMapping,
+    TypeLike,
 )
 
 if TYPE_CHECKING:
     from collections.abc import Container, Hashable, Sized
 
 
-_P = ParamSpec("_P")
-_T = TypeVar("_T")
-_T1 = TypeVar("_T1")
-_T2 = TypeVar("_T2")
-_T3 = TypeVar("_T3")
-_T4 = TypeVar("_T4")
-_T5 = TypeVar("_T5")
-_U = TypeVar("_U")
-
-
-##
-
-
-def apply_decorators(
-    func: TCallable1, /, *decorators: Callable[[TCallable2], TCallable2]
-) -> TCallable1:
+def apply_decorators[F1: Callable, F2: Callable](
+    func: F1, /, *decorators: Callable[[F2], F2]
+) -> F1:
     """Apply a set of decorators to a function."""
     return reduce(_apply_decorators_one, decorators, func)
 
 
-def _apply_decorators_one(acc: TCallable, el: Callable[[Any], Any], /) -> TCallable:
+def _apply_decorators_one[F: Callable](acc: F, el: Callable[[Any], Any], /) -> F:
     return el(acc)
 
 
@@ -123,66 +108,64 @@ class EnsureBytesError(Exception):
 
 
 @overload
-def ensure_class(obj: Any, cls: type[_T], /, *, nullable: bool) -> _T | None: ...
+def ensure_class[T](obj: Any, cls: type[T], /, *, nullable: bool) -> T | None: ...
 @overload
-def ensure_class(
-    obj: Any, cls: type[_T], /, *, nullable: Literal[False] = False
-) -> _T: ...
+def ensure_class[T](
+    obj: Any, cls: type[T], /, *, nullable: Literal[False] = False
+) -> T: ...
 @overload
-def ensure_class(
-    obj: Any, cls: tuple[type[_T1], type[_T2]], /, *, nullable: bool
-) -> _T1 | _T2 | None: ...
+def ensure_class[T1, T2](
+    obj: Any, cls: tuple[type[T1], type[T2]], /, *, nullable: bool
+) -> T1 | T2 | None: ...
 @overload
-def ensure_class(
-    obj: Any, cls: tuple[type[_T1], type[_T2]], /, *, nullable: Literal[False] = False
-) -> _T1 | _T2: ...
+def ensure_class[T1, T2](
+    obj: Any, cls: tuple[type[T1], type[T2]], /, *, nullable: Literal[False] = False
+) -> T1 | T2: ...
 @overload
-def ensure_class(
-    obj: Any, cls: tuple[type[_T1], type[_T2], type[_T3]], /, *, nullable: bool
-) -> _T1 | _T2 | _T3 | None: ...
+def ensure_class[T1, T2, T3](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3]], /, *, nullable: bool
+) -> T1 | T2 | T3 | None: ...
 @overload
-def ensure_class(
+def ensure_class[T1, T2, T3](
     obj: Any,
-    cls: tuple[type[_T1], type[_T2], type[_T3]],
+    cls: tuple[type[T1], type[T2], type[T3]],
     /,
     *,
     nullable: Literal[False] = False,
-) -> _T1 | _T2 | _T3: ...
+) -> T1 | T2 | T3: ...
 @overload
-def ensure_class(
+def ensure_class[T1, T2, T3, T4](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3], type[T4]], /, *, nullable: bool
+) -> T1 | T2 | T3 | T4 | None: ...
+@overload
+def ensure_class[T1, T2, T3, T4](
     obj: Any,
-    cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4]],
+    cls: tuple[type[T1], type[T2], type[T3], type[T4]],
+    /,
+    *,
+    nullable: Literal[False] = False,
+) -> T1 | T2 | T3 | T4: ...
+@overload
+def ensure_class[T1, T2, T3, T4, T5](
+    obj: Any,
+    cls: tuple[type[T1], type[T2], type[T3], type[T4], type[T5]],
     /,
     *,
     nullable: bool,
-) -> _T1 | _T2 | _T3 | _T4 | None: ...
+) -> T1 | T2 | T3 | T4 | T5 | None: ...
 @overload
-def ensure_class(
+def ensure_class[T1, T2, T3, T4, T5](
     obj: Any,
-    cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4]],
+    cls: tuple[type[T1], type[T2], type[T3], type[T4], type[T5]],
     /,
     *,
     nullable: Literal[False] = False,
-) -> _T1 | _T2 | _T3 | _T4: ...
+) -> T1 | T2 | T3 | T4 | T5: ...
 @overload
-def ensure_class(
-    obj: Any,
-    cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4], type[_T5]],
-    /,
-    *,
-    nullable: bool,
-) -> _T1 | _T2 | _T3 | _T4 | _T5 | None: ...
-@overload
-def ensure_class(
-    obj: Any,
-    cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4], type[_T5]],
-    /,
-    *,
-    nullable: Literal[False] = False,
-) -> _T1 | _T2 | _T3 | _T4 | _T5: ...
-def ensure_class(
-    obj: Any, cls: type[_T] | tuple[type[_T], ...], /, *, nullable: bool = False
-) -> Any:
+def ensure_class[T](
+    obj: Any, cls: TypeLike[T], /, *, nullable: bool = False
+) -> Any: ...
+def ensure_class[T](obj: Any, cls: TypeLike[T], /, *, nullable: bool = False) -> Any:
     """Ensure an object is of the required class."""
     if isinstance(obj, cls) or ((obj is None) and nullable):
         return obj
@@ -192,7 +175,7 @@ def ensure_class(
 @dataclass(kw_only=True, slots=True)
 class EnsureClassError(Exception):
     obj: Any
-    cls: type[Any] | tuple[type[Any], ...]
+    cls: TypeLike[Any]
     nullable: bool
 
     @override
@@ -208,13 +191,13 @@ class EnsureClassError(Exception):
 
 
 @overload
-def ensure_date(obj: Any, /, *, nullable: bool) -> dt.date | None: ...
+def ensure_date(obj: Any, /, *, nullable: bool) -> Date | None: ...
 @overload
-def ensure_date(obj: Any, /, *, nullable: Literal[False] = False) -> dt.date: ...
-def ensure_date(obj: Any, /, *, nullable: bool = False) -> dt.date | None:
+def ensure_date(obj: Any, /, *, nullable: Literal[False] = False) -> Date: ...
+def ensure_date(obj: Any, /, *, nullable: bool = False) -> Date | None:
     """Ensure an object is a date."""
     try:
-        return ensure_class(obj, dt.date, nullable=nullable)
+        return ensure_class(obj, Date, nullable=nullable)
     except EnsureClassError as error:
         raise EnsureDateError(obj=error.obj, nullable=nullable) from None
 
@@ -232,33 +215,6 @@ class EnsureDateError(Exception):
 ##
 
 
-@overload
-def ensure_datetime(obj: Any, /, *, nullable: bool) -> dt.datetime | None: ...
-@overload
-def ensure_datetime(
-    obj: Any, /, *, nullable: Literal[False] = False
-) -> dt.datetime: ...
-def ensure_datetime(obj: Any, /, *, nullable: bool = False) -> dt.datetime | None:
-    """Ensure an object is a datetime."""
-    try:
-        return ensure_class(obj, dt.datetime, nullable=nullable)
-    except EnsureClassError as error:
-        raise EnsureDateTimeError(obj=error.obj, nullable=nullable) from None
-
-
-@dataclass(kw_only=True, slots=True)
-class EnsureDateTimeError(Exception):
-    obj: Any
-    nullable: bool
-
-    @override
-    def __str__(self) -> str:
-        return _make_error_msg(self.obj, "a datetime", nullable=self.nullable)
-
-
-##
-
-
 @overload
 def ensure_float(obj: Any, /, *, nullable: bool) -> float | None: ...
 @overload
@@ -329,16 +285,16 @@ class EnsureIntError(Exception):
 
 
 @overload
-def ensure_member(
-    obj: Any, container: Container[_T], /, *, nullable: bool
-) -> _T | None: ...
+def ensure_member[T](
+    obj: Any, container: Container[T], /, *, nullable: bool
+) -> T | None: ...
 @overload
-def ensure_member(
-    obj: Any, container: Container[_T], /, *, nullable: Literal[False] = False
-) -> _T: ...
-def ensure_member(
-    obj: Any, container: Container[_T], /, *, nullable: bool = False
-) -> _T | None:
+def ensure_member[T](
+    obj: Any, container: Container[T], /, *, nullable: Literal[False] = False
+) -> T: ...
+def ensure_member[T](
+    obj: Any, container: Container[T], /, *, nullable: bool = False
+) -> T | None:
     """Ensure an object is a member of the container."""
     if (obj in container) or ((obj is None) and nullable):
         return obj
@@ -361,7 +317,7 @@ class EnsureMemberError(Exception):
 ##
 
 
-def ensure_not_none(obj: _T | None, /, *, desc: str = "Object") -> _T:
+def ensure_not_none[T](obj: T | None, /, *, desc: str = "Object") -> T:
     """Ensure an object is not None."""
     if obj is None:
         raise EnsureNotNoneError(desc=desc)
@@ -405,6 +361,60 @@ class EnsureNumberError(Exception):
 ##
 
 
+@overload
+def ensure_path(obj: Any, /, *, nullable: bool) -> Path | None: ...
+@overload
+def ensure_path(obj: Any, /, *, nullable: Literal[False] = False) -> Path: ...
+def ensure_path(obj: Any, /, *, nullable: bool = False) -> Path | None:
+    """Ensure an object is a Path."""
+    try:
+        return ensure_class(obj, Path, nullable=nullable)
+    except EnsureClassError as error:
+        raise EnsurePathError(obj=error.obj, nullable=nullable) from None
+
+
+@dataclass(kw_only=True, slots=True)
+class EnsurePathError(Exception):
+    obj: Any
+    nullable: bool
+
+    @override
+    def __str__(self) -> str:
+        return _make_error_msg(self.obj, "a Path", nullable=self.nullable)
+
+
+##
+
+
+@overload
+def ensure_plain_date_time(obj: Any, /, *, nullable: bool) -> PlainDateTime | None: ...
+@overload
+def ensure_plain_date_time(
+    obj: Any, /, *, nullable: Literal[False] = False
+) -> PlainDateTime: ...
+def ensure_plain_date_time(
+    obj: Any, /, *, nullable: bool = False
+) -> PlainDateTime | None:
+    """Ensure an object is a plain date-time."""
+    try:
+        return ensure_class(obj, PlainDateTime, nullable=nullable)
+    except EnsureClassError as error:
+        raise EnsurePlainDateTimeError(obj=error.obj, nullable=nullable) from None
+
+
+@dataclass(kw_only=True, slots=True)
+class EnsurePlainDateTimeError(Exception):
+    obj: Any
+    nullable: bool
+
+    @override
+    def __str__(self) -> str:
+        return _make_error_msg(self.obj, "a plain date-time", nullable=self.nullable)
+
+
+##
+
+
 def ensure_sized(obj: Any, /) -> Sized:
     """Ensure an object is sized."""
     if is_sized(obj):
@@ -469,13 +479,13 @@ class EnsureStrError(Exception):
 
 
 @overload
-def ensure_time(obj: Any, /, *, nullable: bool) -> dt.time | None: ...
+def ensure_time(obj: Any, /, *, nullable: bool) -> Time | None: ...
 @overload
-def ensure_time(obj: Any, /, *, nullable: Literal[False] = False) -> dt.time: ...
-def ensure_time(obj: Any, /, *, nullable: bool = False) -> dt.time | None:
+def ensure_time(obj: Any, /, *, nullable: Literal[False] = False) -> Time: ...
+def ensure_time(obj: Any, /, *, nullable: bool = False) -> Time | None:
     """Ensure an object is a time."""
     try:
-        return ensure_class(obj, dt.time, nullable=nullable)
+        return ensure_class(obj, Time, nullable=nullable)
     except EnsureClassError as error:
         raise EnsureTimeError(obj=error.obj, nullable=nullable) from None
 
@@ -494,15 +504,15 @@ class EnsureTimeError(Exception):
 
 
 @overload
-def ensure_timedelta(obj: Any, /, *, nullable: bool) -> dt.timedelta | None: ...
+def ensure_time_delta(obj: Any, /, *, nullable: bool) -> TimeDelta | None: ...
 @overload
-def ensure_timedelta(
+def ensure_time_delta(
     obj: Any, /, *, nullable: Literal[False] = False
-) -> dt.timedelta: ...
-def ensure_timedelta(obj: Any, /, *, nullable: bool = False) -> dt.timedelta | None:
+) -> TimeDelta: ...
+def ensure_time_delta(obj: Any, /, *, nullable: bool = False) -> TimeDelta | None:
     """Ensure an object is a timedelta."""
     try:
-        return ensure_class(obj, dt.timedelta, nullable=nullable)
+        return ensure_class(obj, TimeDelta, nullable=nullable)
     except EnsureClassError as error:
         raise EnsureTimeDeltaError(obj=error.obj, nullable=nullable) from None
 
@@ -514,13 +524,42 @@ class EnsureTimeDeltaError(Exception):
 
     @override
     def __str__(self) -> str:
-        return _make_error_msg(self.obj, "a timedelta", nullable=self.nullable)
+        return _make_error_msg(self.obj, "a time-delta", nullable=self.nullable)
 
 
 ##
 
 
-def first(pair: tuple[_T, Any], /) -> _T:
+@overload
+def ensure_zoned_date_time(obj: Any, /, *, nullable: bool) -> ZonedDateTime | None: ...
+@overload
+def ensure_zoned_date_time(
+    obj: Any, /, *, nullable: Literal[False] = False
+) -> ZonedDateTime: ...
+def ensure_zoned_date_time(
+    obj: Any, /, *, nullable: bool = False
+) -> ZonedDateTime | None:
+    """Ensure an object is a zoned date-time."""
+    try:
+        return ensure_class(obj, ZonedDateTime, nullable=nullable)
+    except EnsureClassError as error:
+        raise EnsureZonedDateTimeError(obj=error.obj, nullable=nullable) from None
+
+
+@dataclass(kw_only=True, slots=True)
+class EnsureZonedDateTimeError(Exception):
+    obj: Any
+    nullable: bool
+
+    @override
+    def __str__(self) -> str:
+        return _make_error_msg(self.obj, "a zoned date-time", nullable=self.nullable)
+
+
+##
+
+
+def first[T](pair: tuple[T, Any], /) -> T:
     """Get the first element in a pair."""
     return pair[0]
 
@@ -529,10 +568,10 @@ def first(pair: tuple[_T, Any], /) -> _T:
 
 
 @overload
-def get_class(obj: type[_T], /) -> type[_T]: ...
+def get_class[T](obj: type[T], /) -> type[T]: ...
 @overload
-def get_class(obj: _T, /) -> type[_T]: ...
-def get_class(obj: _T | type[_T], /) -> type[_T]:
+def get_class[T](obj: T, /) -> type[T]: ...
+def get_class[T](obj: T | type[T], /) -> type[T]:
     """Get the class of an object, unless it is already a class."""
     return obj if isinstance(obj, type) else type(obj)
 
@@ -596,7 +635,7 @@ def get_func_qualname(obj: Callable[..., Any], /) -> str:
 ##
 
 
-def identity(obj: _T, /) -> _T:
+def identity[T](obj: T, /) -> T:
     """Return the object itself."""
     return obj
 
@@ -633,26 +672,30 @@ def is_hashable(obj: Any, /) -> TypeGuard[Hashable]:
 
 
 @overload
-def is_iterable_of(obj: Any, cls: type[_T], /) -> TypeGuard[Iterable[_T]]: ...
+def is_iterable_of[T](obj: Any, cls: type[T], /) -> TypeGuard[Iterable[T]]: ...
 @overload
-def is_iterable_of(obj: Any, cls: tuple[type[_T1]], /) -> TypeGuard[Iterable[_T1]]: ...
+def is_iterable_of[T1](
+    obj: Any, cls: tuple[type[T1]], /
+) -> TypeGuard[Iterable[T1]]: ...
 @overload
-def is_iterable_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2]], /
-) -> TypeGuard[Iterable[_T1 | _T2]]: ...
+def is_iterable_of[T1, T2](
+    obj: Any, cls: tuple[type[T1], type[T2]], /
+) -> TypeGuard[Iterable[T1 | T2]]: ...
 @overload
-def is_iterable_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2], type[_T3]], /
-) -> TypeGuard[Iterable[_T1 | _T2 | _T3]]: ...
+def is_iterable_of[T1, T2, T3](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3]], /
+) -> TypeGuard[Iterable[T1 | T2 | T3]]: ...
 @overload
-def is_iterable_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4]], /
-) -> TypeGuard[Iterable[_T1 | _T2 | _T3 | _T4]]: ...
+def is_iterable_of[T1, T2, T3, T4](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3], type[T4]], /
+) -> TypeGuard[Iterable[T1 | T2 | T3 | T4]]: ...
 @overload
-def is_iterable_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4], type[_T5]], /
-) -> TypeGuard[Iterable[_T1 | _T2 | _T3 | _T4 | _T5]]: ...
-def is_iterable_of(obj: Any, cls: Any, /) -> TypeGuard[Iterable[Any]]:
+def is_iterable_of[T1, T2, T3, T4, T5](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3], type[T4], type[T5]], /
+) -> TypeGuard[Iterable[T1 | T2 | T3 | T4 | T5]]: ...
+@overload
+def is_iterable_of[T](obj: Any, cls: TypeLike[T], /) -> TypeGuard[Iterable[T]]: ...
+def is_iterable_of[T](obj: Any, cls: TypeLike[T], /) -> TypeGuard[Iterable[T]]:
     """Check if an object is a iterable of tuple or string mappings."""
     return isinstance(obj, Iterable) and all(map(make_isinstance(cls), obj))
 
@@ -677,26 +720,30 @@ def is_not_none(obj: Any, /) -> bool:
 
 
 @overload
-def is_sequence_of(obj: Any, cls: type[_T], /) -> TypeGuard[Sequence[_T]]: ...
+def is_sequence_of[T](obj: Any, cls: type[T], /) -> TypeGuard[Sequence[T]]: ...
 @overload
-def is_sequence_of(obj: Any, cls: tuple[type[_T1]], /) -> TypeGuard[Sequence[_T1]]: ...
+def is_sequence_of[T1](
+    obj: Any, cls: tuple[type[T1]], /
+) -> TypeGuard[Sequence[T1]]: ...
 @overload
-def is_sequence_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2]], /
-) -> TypeGuard[Sequence[_T1 | _T2]]: ...
+def is_sequence_of[T1, T2](
+    obj: Any, cls: tuple[type[T1], type[T2]], /
+) -> TypeGuard[Sequence[T1 | T2]]: ...
 @overload
-def is_sequence_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2], type[_T3]], /
-) -> TypeGuard[Sequence[_T1 | _T2 | _T3]]: ...
+def is_sequence_of[T1, T2, T3](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3]], /
+) -> TypeGuard[Sequence[T1 | T2 | T3]]: ...
 @overload
-def is_sequence_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4]], /
-) -> TypeGuard[Sequence[_T1 | _T2 | _T3 | _T4]]: ...
+def is_sequence_of[T1, T2, T3, T4](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3], type[T4]], /
+) -> TypeGuard[Sequence[T1 | T2 | T3 | T4]]: ...
 @overload
-def is_sequence_of(
-    obj: Any, cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4], type[_T5]], /
-) -> TypeGuard[Sequence[_T1 | _T2 | _T3 | _T4 | _T5]]: ...
-def is_sequence_of(obj: Any, cls: Any, /) -> TypeGuard[Sequence[Any]]:
+def is_sequence_of[T1, T2, T3, T4, T5](
+    obj: Any, cls: tuple[type[T1], type[T2], type[T3], type[T4], type[T5]], /
+) -> TypeGuard[Sequence[T1 | T2 | T3 | T4 | T5]]: ...
+@overload
+def is_sequence_of[T](obj: Any, cls: TypeLike[T], /) -> TypeGuard[Sequence[T]]: ...
+def is_sequence_of[T](obj: Any, cls: TypeLike[T], /) -> TypeGuard[Sequence[T]]:
     """Check if an object is a sequence of tuple or string mappings."""
     return isinstance(obj, Sequence) and is_iterable_of(obj, cls)
 
@@ -742,14 +789,6 @@ def is_string_mapping(obj: Any, /) -> TypeGuard[StrMapping]:
 ##
 
 
-def is_subclass_except_bool_int(x: type[Any], y: type[Any], /) -> bool:
-    """Check for the subclass relation, except bool < int."""
-    return issubclass(x, y) and not (issubclass(x, bool) and issubclass(int, y))
-
-
-##
-
-
 def is_tuple(obj: Any, /) -> TypeGuard[tuple[Any, ...]]:
     """Check if an object is a tuple or string mapping."""
     return make_isinstance(tuple)(obj)
@@ -767,51 +806,42 @@ def is_tuple_or_str_mapping(obj: Any, /) -> TypeGuard[TupleOrStrMapping]:
 
 
 @overload
-def make_isinstance(cls: type[_T], /) -> Callable[[Any], TypeGuard[_T]]: ...
+def make_isinstance[T](cls: type[T], /) -> Callable[[Any], TypeGuard[T]]: ...
 @overload
-def make_isinstance(cls: tuple[type[_T1]], /) -> Callable[[Any], TypeGuard[_T1]]: ...
+def make_isinstance[T1](cls: tuple[type[T1]], /) -> Callable[[Any], TypeGuard[T1]]: ...
 @overload
-def make_isinstance(
-    cls: tuple[type[_T1], type[_T2]], /
-) -> Callable[[Any], TypeGuard[_T1 | _T2]]: ...
+def make_isinstance[T1, T2](
+    cls: tuple[type[T1], type[T2]], /
+) -> Callable[[Any], TypeGuard[T1 | T2]]: ...
 @overload
-def make_isinstance(
-    cls: tuple[type[_T1], type[_T2], type[_T3]], /
-) -> Callable[[Any], TypeGuard[_T1 | _T2 | _T3]]: ...
+def make_isinstance[T1, T2, T3](
+    cls: tuple[type[T1], type[T2], type[T3]], /
+) -> Callable[[Any], TypeGuard[T1 | T2 | T3]]: ...
 @overload
-def make_isinstance(
-    cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4]], /
-) -> Callable[[Any], TypeGuard[_T1 | _T2 | _T3 | _T4]]: ...
+def make_isinstance[T1, T2, T3, T4](
+    cls: tuple[type[T1], type[T2], type[T3], type[T4]], /
+) -> Callable[[Any], TypeGuard[T1 | T2 | T3 | T4]]: ...
 @overload
-def make_isinstance(
-    cls: tuple[type[_T1], type[_T2], type[_T3], type[_T4], type[_T5]], /
-) -> Callable[[Any], TypeGuard[_T1 | _T2 | _T3 | _T4 | _T5]]: ...
-def make_isinstance(
-    cls: type[_T] | tuple[type[_T], ...], /
-) -> Callable[[Any], TypeGuard[Any]]:
+def make_isinstance[T1, T2, T3, T4, T5](
+    cls: tuple[type[T1], type[T2], type[T3], type[T4], type[T5]], /
+) -> Callable[[Any], TypeGuard[T1 | T2 | T3 | T4 | T5]]: ...
+@overload
+def make_isinstance[T](cls: TypeLike[T], /) -> Callable[[Any], TypeGuard[T]]: ...
+def make_isinstance[T](cls: TypeLike[T], /) -> Callable[[Any], TypeGuard[T]]:
     """Make a curried `isinstance` function."""
     return partial(_make_instance_core, cls=cls)
 
 
-##
-
-
-def _make_instance_core(
-    obj: Any, /, *, cls: type[_T] | tuple[type[_T], ...]
-) -> TypeGuard[_T]:
+def _make_instance_core[T](obj: Any, /, *, cls: TypeLike[T]) -> TypeGuard[T]:
     return isinstance(obj, cls)
 
 
 ##
 
 
-def map_object(
-    func: Callable[[Any], Any],
-    obj: _T,
-    /,
-    *,
-    before: Callable[[Any], Any] | None = None,
-) -> _T:
+def map_object[T](
+    func: Callable[[Any], Any], obj: T, /, *, before: Callable[[Any], Any] | None = None
+) -> T:
     """Map a function over an object, across a variety of structures."""
     if before is not None:
         obj = before(obj)
@@ -832,19 +862,16 @@ def map_object(
 
 
 @overload
-def min_nullable(
-    iterable: Iterable[TSupportsRichComparison | None], /, *, default: Sentinel = ...
-) -> TSupportsRichComparison: ...
+def min_nullable[T: SupportsRichComparison](
+    iterable: Iterable[T | None], /, *, default: Sentinel = ...
+) -> T: ...
 @overload
-def min_nullable(
-    iterable: Iterable[TSupportsRichComparison | None], /, *, default: _U = ...
-) -> TSupportsRichComparison | _U: ...
-def min_nullable(
-    iterable: Iterable[TSupportsRichComparison | None],
-    /,
-    *,
-    default: _U | Sentinel = sentinel,
-) -> TSupportsRichComparison | _U:
+def min_nullable[T: SupportsRichComparison, U](
+    iterable: Iterable[T | None], /, *, default: U = ...
+) -> T | U: ...
+def min_nullable[T: SupportsRichComparison, U](
+    iterable: Iterable[T | None], /, *, default: U | Sentinel = sentinel
+) -> T | U:
     """Compute the minimum of a set of values; ignoring nulls."""
     values = (i for i in iterable if i is not None)
     if isinstance(default, Sentinel):
@@ -856,8 +883,8 @@ def min_nullable(
 
 
 @dataclass(kw_only=True, slots=True)
-class MinNullableError(Exception, Generic[TSupportsRichComparison]):
-    values: Iterable[TSupportsRichComparison]
+class MinNullableError[T: SupportsRichComparison](Exception):
+    values: Iterable[T]
 
     @override
     def __str__(self) -> str:
@@ -865,19 +892,16 @@ class MinNullableError(Exception, Generic[TSupportsRichComparison]):
 
 
 @overload
-def max_nullable(
-    iterable: Iterable[TSupportsRichComparison | None], /, *, default: Sentinel = ...
-) -> TSupportsRichComparison: ...
+def max_nullable[T: SupportsRichComparison](
+    iterable: Iterable[T | None], /, *, default: Sentinel = ...
+) -> T: ...
 @overload
-def max_nullable(
-    iterable: Iterable[TSupportsRichComparison | None], /, *, default: _U = ...
-) -> TSupportsRichComparison | _U: ...
-def max_nullable(
-    iterable: Iterable[TSupportsRichComparison | None],
-    /,
-    *,
-    default: _U | Sentinel = sentinel,
-) -> TSupportsRichComparison | _U:
+def max_nullable[T: SupportsRichComparison, U](
+    iterable: Iterable[T | None], /, *, default: U = ...
+) -> T | U: ...
+def max_nullable[T: SupportsRichComparison, U](
+    iterable: Iterable[T | None], /, *, default: U | Sentinel = sentinel
+) -> T | U:
     """Compute the maximum of a set of values; ignoring nulls."""
     values = (i for i in iterable if i is not None)
     if isinstance(default, Sentinel):
@@ -889,7 +913,7 @@ def max_nullable(
 
 
 @dataclass(kw_only=True, slots=True)
-class MaxNullableError(Exception, Generic[TSupportsRichComparison]):
+class MaxNullableError[TSupportsRichComparison](Exception):
     values: Iterable[TSupportsRichComparison]
 
     @override
@@ -900,11 +924,11 @@ class MaxNullableError(Exception, Generic[TSupportsRichComparison]):
 ##
 
 
-def not_func(func: Callable[_P, bool], /) -> Callable[_P, bool]:
+def not_func[**P](func: Callable[P, bool], /) -> Callable[P, bool]:
     """Lift a boolean-valued function to return its conjugation."""
 
     @wraps(func)
-    def wrapped(*args: _P.args, **kwargs: _P.kwargs) -> bool:
+    def wrapped(*args: P.args, **kwargs: P.kwargs) -> bool:
         return not func(*args, **kwargs)
 
     return wrapped
@@ -913,7 +937,7 @@ def not_func(func: Callable[_P, bool], /) -> Callable[_P, bool]:
 ##
 
 
-def second(pair: tuple[Any, _U], /) -> _U:
+def second[U](pair: tuple[Any, U], /) -> U:
     """Get the second element in a pair."""
     return pair[1]
 
@@ -921,6 +945,28 @@ def second(pair: tuple[Any, _U], /) -> _U:
 ##
 
 
+@overload
+def to_bool(*, bool_: MaybeCallableBool) -> bool: ...
+@overload
+def to_bool(*, bool_: None) -> None: ...
+@overload
+def to_bool(*, bool_: Sentinel) -> Sentinel: ...
+def to_bool(
+    *, bool_: MaybeCallableBool | None | Sentinel = sentinel
+) -> bool | None | Sentinel:
+    """Get the bool."""
+    match bool_:
+        case bool() | None | Sentinel():
+            return bool_
+        case Callable() as func:
+            return to_bool(bool_=func())
+        case _ as never:
+            assert_never(never)
+
+
+##
+
+
 def yield_object_attributes(
     obj: Any,
     /,
@@ -970,18 +1016,20 @@ __all__ = [
     "EnsureBytesError",
     "EnsureClassError",
     "EnsureDateError",
-    "EnsureDateTimeError",
     "EnsureFloatError",
     "EnsureHashableError",
     "EnsureIntError",
     "EnsureMemberError",
     "EnsureNotNoneError",
     "EnsureNumberError",
+    "EnsurePathError",
+    "EnsurePlainDateTimeError",
     "EnsureSizedError",
     "EnsureSizedNotStrError",
     "EnsureStrError",
     "EnsureTimeDeltaError",
     "EnsureTimeError",
+    "EnsureZonedDateTimeError",
     "MaxNullableError",
     "MinNullableError",
     "apply_decorators",
@@ -989,18 +1037,20 @@ __all__ = [
     "ensure_bytes",
     "ensure_class",
     "ensure_date",
-    "ensure_datetime",
     "ensure_float",
     "ensure_hashable",
     "ensure_int",
     "ensure_member",
     "ensure_not_none",
     "ensure_number",
+    "ensure_path",
+    "ensure_plain_date_time",
     "ensure_sized",
     "ensure_sized_not_str",
     "ensure_str",
     "ensure_time",
-    "ensure_timedelta",
+    "ensure_time_delta",
+    "ensure_zoned_date_time",
     "first",
     "get_class",
     "get_class_name",
@@ -1017,7 +1067,6 @@ __all__ = [
     "is_sized",
     "is_sized_not_str",
     "is_string_mapping",
-    "is_subclass_except_bool_int",
     "is_tuple",
     "is_tuple_or_str_mapping",
     "make_isinstance",
