@@ -1,22 +1,26 @@
 from __future__ import annotations
 
+from collections.abc import Sequence
 from dataclasses import dataclass
-from functools import reduce
+from functools import partial, reduce
 from itertools import repeat
-from typing import TYPE_CHECKING, Any, overload, override
+from typing import TYPE_CHECKING, Any, SupportsIndex, overload, override
 
 import numpy as np
 from numpy import (
+    argsort,
     array,
     bool_,
+    complex128,
     digitize,
     dtype,
     errstate,
+    exp,
     flatnonzero,
-    float64,
+    floating,
     full_like,
     inf,
-    int64,
+    integer,
     isclose,
     isfinite,
     isinf,
@@ -30,14 +34,20 @@ from numpy import (
     roll,
     where,
 )
+from numpy.fft import fft, fftfreq, ifft
 from numpy.linalg import det, eig
 from numpy.random import default_rng
 from numpy.typing import NDArray
 
-from utilities.iterables import is_iterable_not_str
+from utilities.iterables import always_iterable, is_iterable_not_str
 
 if TYPE_CHECKING:
-    from collections.abc import Iterable
+    from collections.abc import Callable, Iterable
+
+    from utilities.types import MaybeIterable
+
+
+type ShapeLike = SupportsIndex | Sequence[SupportsIndex]
 
 
 ##
@@ -84,8 +94,9 @@ timedelta64as = dtype("timedelta64[as]")
 
 NDArrayA = NDArray[Any]
 NDArrayB = NDArray[bool_]
-NDArrayF = NDArray[float64]
-NDArrayI = NDArray[int64]
+NDArrayC128 = NDArray[complex128]
+NDArrayF = NDArray[floating[Any]]
+NDArrayI = NDArray[integer[Any]]
 NDArrayO = NDArray[object_]
 
 
@@ -129,6 +140,78 @@ class AsIntError(Exception): ...
 ##
 
 
+def bernoulli(
+    *, true: float = 0.5, seed: int | None = None, size: ShapeLike = ()
+) -> NDArrayB:
+    """Return a set of Bernoulli random variates."""
+    from numpy.random import default_rng
+
+    rng = default_rng(seed=seed)
+    return rng.binomial(1, true, size=size).astype(bool)
+
+
+##
+
+
+def boxcar(
+    array: NDArrayF,
+    /,
+    *,
+    loc_low: float = -1.0,
+    slope_low: float = 1.0,
+    loc_high: float = 1.0,
+    slope_high: float = 1.0,
+    rtol: float | None = None,
+    atol: float | None = None,
+) -> NDArrayF:
+    """Construct a boxcar function."""
+    if not is_at_most(loc_low, loc_high, rtol=rtol, atol=atol):
+        raise _BoxCarLocationsError(low=loc_low, high=loc_high)
+    if not is_positive(slope_low, rtol=rtol, atol=atol):
+        raise _BoxCarLowerBoundSlopeError(slope=slope_low)
+    if not is_positive(slope_high, rtol=rtol, atol=atol):
+        raise _BoxCarUpperBoundSlopeError(slope=slope_high)
+    return (
+        sigmoid(array, loc=loc_low, slope=slope_low)
+        + sigmoid(array, loc=loc_high, slope=-slope_high)
+    ) / 2
+
+
+@dataclass(kw_only=True, slots=True)
+class BoxCarError(Exception): ...
+
+
+@dataclass(kw_only=True, slots=True)
+class _BoxCarLocationsError(BoxCarError):
+    low: float
+    high: float
+
+    @override
+    def __str__(self) -> str:
+        return f"Location parameters must be consistent; got {self.low} and {self.high}"
+
+
+@dataclass(kw_only=True, slots=True)
+class _BoxCarLowerBoundSlopeError(BoxCarError):
+    slope: float
+
+    @override
+    def __str__(self) -> str:
+        return f"Lower-bound slope parameter must be positive; got {self.slope}"
+
+
+@dataclass(kw_only=True, slots=True)
+class _BoxCarUpperBoundSlopeError(BoxCarError):
+    slope: float
+
+    @override
+    def __str__(self) -> str:
+        return f"Upper-bound slope parameter must be positive; got {self.slope}"
+
+
+##
+
+
 def discretize(x: NDArrayF, bins: int | Iterable[float], /) -> NDArrayF:
     """Discretize an array of floats.
 
@@ -160,6 +243,48 @@ def fillna(array: NDArrayF, /, *, value: float = 0.0) -> NDArrayF:
 ##
 
 
+def adjust_frequencies(
+    array: NDArrayF,
+    /,
+    *,
+    filters: MaybeIterable[Callable[[NDArrayF], NDArrayB]] | None = None,
+    weights: MaybeIterable[Callable[[NDArrayF], NDArrayF]] | None = None,
+    d: int = 1,
+) -> NDArrayF:
+    """Adjust an array via its FFT frequencies."""
+    (n,) = array.shape
+    amplitudes = fft(array)
+    freqs = fftfreq(n, d=d)
+    if filters is not None:
+        amplitudes = reduce(
+            partial(_adjust_frequencies_filter_one, freqs=freqs),
+            always_iterable(filters),
+            amplitudes,
+        )
+    if weights is not None:
+        amplitudes = reduce(
+            partial(_adjust_frequencies_weight_one, freqs=freqs),
+            always_iterable(weights),
+            amplitudes,
+        )
+    return ifft(amplitudes).real
+
+
+def _adjust_frequencies_filter_one(
+    acc: NDArrayC128, el: Callable[[NDArrayF], NDArrayB], /, *, freqs: NDArrayF
+) -> NDArrayC128:
+    return where(el(freqs), acc, 0.0)
+
+
+def _adjust_frequencies_weight_one(
+    acc: NDArrayC128, el: Callable[[NDArrayF], NDArrayF], /, *, freqs: NDArrayF
+) -> NDArrayC128:
+    return acc * el(freqs)
+
+
+##
+
+
 def flatn0(array: NDArrayB, /) -> int:
     """Return the index of the unique True element."""
     if not array.any():
@@ -193,6 +318,19 @@ class FlatN0MultipleError(FlatN0Error):
 ##
 
 
+def get_frequency_spectrum(array: NDArrayF, /, *, d: int = 1) -> NDArrayF:
+    """Get the frequency spectrum."""
+    (n,) = array.shape
+    amplitudes = fft(array)
+    freqs = fftfreq(n, d=d)
+    amplitudes = np.abs(amplitudes)
+    data = np.hstack([freqs.reshape(-1, 1), amplitudes.reshape(-1, 1)])
+    return data[argsort(data[:, 0])]
+
+
+##
+
+
 def has_dtype(x: Any, dtype: Any, /) -> bool:
     """Check if an object has the required dtype."""
     if is_iterable_not_str(dtype):
@@ -803,6 +941,31 @@ def shift_bool(
 ##
 
 
+def sigmoid(
+    array: NDArrayF,
+    /,
+    *,
+    loc: float = 0.0,
+    slope: float = 1.0,
+    rtol: float | None = None,
+    atol: float | None = None,
+) -> NDArrayF:
+    """Construct a sigmoid function."""
+    if is_zero(slope, rtol=rtol, atol=atol):
+        raise SigmoidError
+    return 1 / (1 + exp(-slope * (array - loc)))
+
+
+@dataclass(kw_only=True, slots=True)
+class SigmoidError(Exception):
+    @override
+    def __str__(self) -> str:
+        return "Slope must be non-zero"
+
+
+##
+
+
 def _is_close(
     x: Any,
     y: Any,
@@ -825,6 +988,7 @@ def _is_close(
 __all__ = [
     "DEFAULT_RNG",
     "AsIntError",
+    "BoxCarError",
     "FlatN0EmptyError",
     "FlatN0Error",
     "FlatN0MultipleError",
@@ -833,9 +997,14 @@ __all__ = [
     "NDArrayF",
     "NDArrayI",
     "NDArrayO",
+    "ShapeLike",
     "ShiftError",
+    "SigmoidError",
+    "adjust_frequencies",
     "array_indexer",
     "as_int",
+    "bernoulli",
+    "boxcar",
     "datetime64D",
     "datetime64M",
     "datetime64W",
@@ -852,6 +1021,7 @@ __all__ = [
     "discretize",
     "fillna",
     "flatn0",
+    "get_frequency_spectrum",
     "has_dtype",
     "is_at_least",
     "is_at_least_or_nan",
@@ -902,4 +1072,5 @@ __all__ = [
     "maximum",
     "minimum",
     "shift_bool",
+    "sigmoid",
 ]
