@@ -9,7 +9,7 @@ from re import IGNORECASE, Match, escape, search
 from textwrap import dedent
 from threading import get_ident
 from time import time_ns
-from typing import TYPE_CHECKING, Any, Literal, overload, override
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, overload, override
 from uuid import uuid4
 
 from utilities.iterables import CheckDuplicatesError, check_duplicates, transpose
@@ -385,6 +385,32 @@ def _escape_separator(*, separator: str = DEFAULT_SEPARATOR) -> str:
 ##
 
 
+class secret_str(str):  # noqa: N801
+    """A string with an obfuscated representation."""
+
+    __slots__ = ("_text",)
+    _REPR: ClassVar[str] = "***"
+
+    def __init__(self, text: str, /) -> None:
+        super().__init__()
+        self._text = text
+
+    @override
+    def __repr__(self) -> str:
+        return self._REPR
+
+    @override
+    def __str__(self) -> str:
+        return self._REPR
+
+    @property
+    def str(self) -> str:
+        return self._text
+
+
+##
+
+
 def str_encode(obj: Any, /) -> bytes:
     """Return the string representation of the object encoded as bytes."""
     return str(obj).encode()
@@ -424,6 +450,7 @@ __all__ = [
     "parse_bool",
     "parse_none",
     "repr_encode",
+    "secret_str",
     "snake_case",
     "split_key_value_pairs",
     "split_str",
